import { useState, useCallback } from 'react';
import { useElectron } from './useElectron';

export function useFileSystem() {
  const electron = useElectron();
  const [watchedDirectories, setWatchedDirectories] = useState<string[]>([]);

  const watchDirectory = useCallback(async (dirPath: string) => {
    try {
      await electron.startWatching(dirPath);
      setWatchedDirectories(prev => [...prev, dirPath]);
    } catch (error) {
      console.error('Error watching directory:', error);
    }
  }, [electron]);

  const unwatchDirectory = useCallback(async (dirPath: string) => {
    try {
      await electron.stopWatching(dirPath);
      setWatchedDirectories(prev => prev.filter(dir => dir !== dirPath));
    } catch (error) {
      console.error('Error unwatching directory:', error);
    }
  }, [electron]);

  const addExcludedPath = useCallback(async (path: string) => {
    try {
      await electron.addExcludedPath(path);
    } catch (error) {
      console.error('Error adding excluded path:', error);
    }
  }, [electron]);

  return {
    watchedDirectories,
    watchDirectory,
    unwatchDirectory,
    addExcludedPath,
  };
}
